#include "proc_operations.h"
#include <stdio.h>
#include <stdlib.h>

char *get_process_name_by_pid(const int pid) {
  char path[1024];
  sprintf(path, "/proc/%d/exe", pid);

  char *name = realpath(path, NULL);
  if (name == NULL) {
    fprintf(stderr, "Could not get process name by pid %d", pid);
    perror("");
  }
  return name;
}

/**
 * Finds the parent process ID of a given process.
 *
 * @param pid: The process ID of the process to find the parent of
 * @return: The parent process ID, or 0 if the parent process ID could not be
 * found
 */
pid_t get_parent_pid(pid_t pid) {
  pid_t ppid = 0;
  char path[256];
  snprintf(path, sizeof(path), "/proc/%u/status", pid);

  FILE *file = fopen(path, "r");
  if (file == NULL) {
    perror("Failed to open /proc/<pid>/status");
    return 0;
  }

  char line[256];
  while (fgets(line, sizeof(line), file)) {
    if (sscanf(line, "PPid:\t%d", &ppid) == 1) {
      fclose(file);
      return ppid;
    }
  }

  fclose(file);
  return 0; // Parent PID not found
}
